@@ -4,10 +4,11 @@ with qw(
     Dist::Zilla::Role::Plugin
 );
 use Git::Wrapper qw();
+use version;
 use namespace::autoclean;
 
 # ABSTRACT: Grant Street Group defaults CPAN dists
-our $VERSION = '0.0.9'; # VERSION
+our $VERSION = '0.0.11'; # VERSION
 
 before 'BUILDARGS' => sub {
     my ($class, $args) = @_;
@@ -19,9 +20,19 @@ before 'BUILDARGS' => sub {
     $args->{zilla}->{_copyright_holder} ||= 'Grant Street Group';
 
     if ( not $args->{zilla}->{_copyright_year} ) {
-        my ( $commit, $date ) = do { local $@; eval { local $SIG{__DIE__};
-            Git::Wrapper->new( $args->{zilla}->root )->RUN(
-                qw( rev-list --max-parents=0 --pretty=format:%ai HEAD )) } };
+        my $git = Git::Wrapper->new( $args->{zilla}->root );
+
+        # We need v1.7.5 of git in order to get all the flags
+        # necessary to do all the things.
+        my $git_version = $git->version || 0;
+        $args->{zilla}
+            ->log_fatal( "[Author::GSG] Git 1.7.5 or greater is required"
+                . ", only have $git_version." )
+            if $git_version < version->parse(v1.7.5);
+
+        local $@;
+        my ( $commit, $date ) = eval { local $SIG{__DIE__};
+            $git->rev_list(qw( --max-parents=0 --pretty=format:%ai HEAD )) };
 
         my $year = 1900 + (localtime)[5];
         if ($date) {
@@ -29,6 +40,9 @@ before 'BUILDARGS' => sub {
             $year = $1 if $date =~ /^(\d{4})/;
             $year .= " - $this_year" unless $year == $this_year;
         }
+        else {
+            $args->{zilla}->log("Didn't find copyright start date: $@");
+        }
 
         $args->{zilla}->{_copyright_year} = $year;
     }
@@ -49,7 +63,7 @@ Dist::Zilla::Plugin::Author::GSG - Grant Street Group defaults CPAN dists
 
 =head1 VERSION
 
-version 0.0.9
+version 0.0.11
 
 =head1 SYNOPSIS
 
